
(* spiralsf.m *)
(* Version 2. *)
(* by Rolf Sulanke *)
(* Date: September 19, 2003 *)

(* Version 1: May 25, 1999. Revised October 4, 2000.*)

(* Summary 
The 1-parameter groups of spiral transformations are defined.
Spiral surface are generated by a given 2D curve under the action of a spiral
transformation group. The curve in the x-z plane generates 
the surface by rotating the curve around the z-axis 
with angle t and dilating it with Exp[a t] simultaneously.
The curve has to be given by a parameter representation of the form
name[u_] := {f1[u], f2[u]}, where f1[u, f2[u] are the components in the
 x,z-plane.
*)

(* Keywords: spiral transformation, spiral surface *)

(* The package has been applied in the notebook Spirals.nb, in which besides of
the surfaces also spirals in the plane, and loxodromes on the sphere are
treated. The package spiralsf.m calls the package euvec.m, a copy of which
should be in the working directory. *)

(* Free software: Feel free to apply, distribute or change the package.
Please, cite the source and notice the
changes, or new concepts,  which you introduced.*)


BeginPackage["spiralsf`",{"euvec`"}]

spiral::usage = 
	"spiral[t,a] is the rotation with angle t around the z-axis and 
	simultaneous dilatation with the factor Exp[t a]."
	
spiralsurface::usage =
	"spiralsurface[xz_List, a:0.1][t,u] is the parameter representation of the 
	spiral surface generated by the curve with parameter representation xz as a
 function of u
	in the x,z-plane; a:0.1 is the default parameter of the generating spiral
 group."

plotspiralsurface::usage =
	"plotspiralsurface[xz_List, a:0.1][t0,t1,u0,u1,opt] is the 3D-plot of 
	the spiralsurface 
	generated by the curve with parameter representation xz as a function 
	of u in the x,z-plane in the range {t,t0,t1},{u,u0,u1}; t1-t0 is the 
	total rotation angle; options opt are transferred to 
	ParametricPlot3D."


	
Begin["`Private`"]

spiral[t_, a_] := {{Cos[t], Sin[t], 0}, {-Sin[t], Cos[t], 0}, 
{0, 0, 1}} Exp[t a]

spiralsurface[func_, a_:0.1][u_, t_] := 
  spiral[t, a] . {func[u][[1]], 0, func[u][[2]]} 
  
plotspiralsurface[func_, a_:0.1][ t0_, t1_, u0_, u1_, opt___] := 
	ParametricPlot3D[Evaluate[spiralsurface[func, a][u, t]], 
	{t, t0, t1},{u, u0, u1}, opt]   

End[]

Protect[spiral, spiralsurface, plotspiralsurface]

(*:Limitations: none known. *)


EndPackage[]

